@@ -1,12 +1,15 @@
-if defined? Gem.loaded_specs and Gem.loaded_specs.include? 'rack'
-  version = Gem.loaded_specs['rack'].version.to_s
-else
-  version = Rack.release + '.0'
-end
+# frozen_string_literal: true
 
-if version == "1.3"
+version = if defined? Gem.loaded_specs&.include?('rack')
+            Gem.loaded_specs['rack'].version.to_s
+          else
+            "#{Rack.release}.0"
+          end
+
+if version == '1.3'
   Rack::Session::Abstract::ID.class_eval do
     private
+
     def prepare_session(env)
       session_was                  = env[ENV_SESSION_KEY]
       env[ENV_SESSION_KEY]         = SessionHash.new(self, env)
