@@ -1,5 +1,5 @@
 # I like coding: UTF-8
-require File.expand_path('../helper', __FILE__)
+require File.expand_path('helper', __dir__)
 
 class CompileTest < Minitest::Test
   def self.parses pattern, example, expected_params, mtype = :sinatra, mopts = {}
