@@ -1,4 +1,4 @@
-require File.expand_path('../helper', __FILE__)
+require File.expand_path('helper', __dir__)
 require 'date'
 require 'json'
 
@@ -781,6 +781,18 @@ class HelpersTest < Minitest::Test
       assert_equal '<sinatra></sinatra>', body
     end
 
+    it 'escapes filename in the Content-Disposition header according to the multipart form data spec in WHATWG living standard' do
+      mock_app do
+        get('/attachment') do
+          attachment "test.xml\";\r\next=.txt"
+          response.write("<sinatra></sinatra>")
+        end
+      end
+
+      get '/attachment'
+      assert_equal 'attachment; filename="test.xml%22;%0D%0Aext=.txt"', response['Content-Disposition']
+      assert_equal '<sinatra></sinatra>', body
+    end
   end
 
   describe 'send_file' do
@@ -979,6 +991,8 @@ class HelpersTest < Minitest::Test
 
         get('/baz') { expires Time.at(0) }
 
+        get('/bah') { expires Time.at(0), :max_age => 20 }
+
         get('/blah') do
           obj = Object.new
           def obj.method_missing(*a, &b) 60.send(*a, &b) end
@@ -1011,6 +1025,12 @@ class HelpersTest < Minitest::Test
       assert_equal 'Thu, 01 Jan 1970 00:00:00 GMT', response['Expires']
     end
 
+    it 'allows max_age to be specified separately' do
+      get '/bah'
+      assert_equal 'Thu, 01 Jan 1970 00:00:00 GMT', response['Expires']
+      assert_equal ['max-age=20'], response['Cache-Control'].split(', ')
+    end
+
     it 'accepts values pretending to be a Numeric (like ActiveSupport::Duration)' do
       get '/blah'
       assert_equal ['public', 'no-cache', 'max-age=60'], response['Cache-Control'].split(', ')
