@@ -22,7 +22,7 @@ module IntegrationHelper
     end
 
     def app_file
-      File.expand_path('../integration/app.rb', __FILE__)
+      File.expand_path('integration/app.rb', __dir__)
     end
 
     def environment
@@ -62,7 +62,7 @@ module IntegrationHelper
           cmd << File.expand_path(file, dir).inspect
         end
         cmd << "-w" unless net_http_server?
-        cmd << "-I" << File.expand_path('../../lib', __FILE__).inspect
+        cmd << "-I" << File.expand_path('../lib', __dir__).inspect
         cmd << app_file.inspect << '-s' << server << '-o' << '127.0.0.1' << '-p' << port
         cmd << "-e" << environment.to_s << '2>&1'
         cmd.join " "
@@ -81,8 +81,8 @@ module IntegrationHelper
       name.to_s == "puma"
     end
 
-    def reel?
-      name.to_s == "reel"
+    def falcon?
+      name.to_s == "falcon"
     end
 
     def trinidad?
@@ -122,7 +122,15 @@ module IntegrationHelper
     super
 
     base_port = 5000 + Process.pid % 100
-    Sinatra::Base.server.each_with_index do |server, index|
+    servers = Sinatra::Base.server.dup
+
+    # TruffleRuby doesn't support `Fiber.set_scheduler` yet
+    unless Fiber.respond_to?(:set_scheduler)
+      warn "skip falcon server"
+      servers.delete('falcon')
+    end
+
+    servers.each_with_index do |server, index|
       Server.run(server, base_port+index)
     end
   end
