@@ -1,5 +1,5 @@
 # I like coding: UTF-8
-require File.expand_path('../helper', __FILE__)
+require File.expand_path('helper', __dir__)
 
 # Helper method for easy route pattern matching testing
 def route_def(pattern)
@@ -358,6 +358,10 @@ class RoutingTest < Minitest::Test
     assert ok?
     assert_equal "foo=hello;bar=", body
 
+    get '/hello?bar=baz'
+    assert ok?
+    assert_equal "foo=hello;bar=baz", body
+
     get '/'
     assert ok?
     assert_equal "foo=;bar=", body
