@@ -1,4 +1,4 @@
-require File.expand_path('../helper', __FILE__)
+require File.expand_path('helper', __dir__)
 
 class SettingsTest < Minitest::Test
   setup do
@@ -488,6 +488,16 @@ class SettingsTest < Minitest::Test
       assert @base.server.include?('puma')
       assert @application.server.include?('puma')
     end
+
+    it 'includes falcon on non-jruby' do
+      if RUBY_ENGINE != 'jruby'
+        assert @base.server.include?('falcon')
+        assert @application.server.include?('falcon')
+      else
+        assert !@base.server.include?('falcon')
+        assert !@application.server.include?('falcon')
+      end
+    end
   end
 
   describe 'app_file' do
